@@ -1,5 +1,5 @@
-package Devel::Trace::Subs;
-use 5.006;
+package Devel::Trace::Subs 0.13;
+use 5.012;
 use strict;
 use warnings;
 
@@ -18,8 +18,6 @@ our @EXPORT_OK = qw(
                     remove_trace
                 );
 
-our $VERSION = '0.12';
-
 $SIG{INT} = sub { 'this ensures END runs if ^C is pressed'; };
 
 sub trace {
@@ -211,26 +209,27 @@ traces.
 
     use Devel::Trace::Subs qw(trace);
 
-    # add a trace() call to the top of all your subs
+Add a trace() call to the top of all your subs
 
     trace(); # or even better: $trace() if $ENV{DTS_ENABLE};
 
-    # enable the module anywhere in the stack (preferably the calling script)
+Enable the module anywhere in the stack (preferably the calling script)
 
     $ENV{DTS_ENABLE} = 1;
 
-    # then from anywhere (typically near the end of the calling script) dump the output
+From anywhere (typically near the end of the calling script) dump the output
 
     trace_dump();
 
-    # automate the installation into a file (or all files in a directory)
+Automate the installation into a file (or all files in a directory)
 
     install_trace(file => 'filename'); # or directory, or 'Module::Name'
 
-    # remove the effects of install_trace()
+Remove the effects of install_trace()
 
     remove_trace(file => 'filename')
 
+See L<EXAMPLES> for further information
 
 =head1 DESCRIPTION
 
