@@ -1,4 +1,5 @@
-package Devel::Trace::Subs::HTML;
+package Devel::Trace::Subs::HTML 0.13;
+use 5.012;
 use strict;
 use warnings;
 
@@ -9,8 +10,6 @@ use HTML::Template;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(html);
 
-our $VERSION = '0.12';
-
 my (@stack_tpl, @flow_tpl, @all_tpl);
 
 sub html {
